@@ -255,12 +255,12 @@ with 'TableDataRole::Business::ID::BPOM::NutritionLabelRef';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-06-13'; # DATE
 our $DIST = 'TableData-Business-ID-BPOM-NutritionLabelRef'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our %STATS = ("num_columns",4,"num_rows",228); # STATS
 
 1;
-# ABSTRACT: Nutrients
+# ABSTRACT: BPOM's nutrition label reference (ALG, acuan label gizi)
 
 __END__
 
@@ -270,11 +270,11 @@ __END__
 
 =head1 NAME
 
-TableDataRole::Business::ID::BPOM::NutritionLabelRef - Nutrients
+TableDataRole::Business::ID::BPOM::NutritionLabelRef - BPOM's nutrition label reference (ALG, acuan label gizi)
 
 =head1 VERSION
 
-This document describes version 0.004 of TableDataRole::Business::ID::BPOM::NutritionLabelRef (from Perl distribution TableData-Business-ID-BPOM-NutritionLabelRef), released on 2024-06-13.
+This document describes version 0.005 of TableDataRole::Business::ID::BPOM::NutritionLabelRef (from Perl distribution TableData-Business-ID-BPOM-NutritionLabelRef), released on 2024-06-13.
 
 =head1 SYNOPSIS
 
